Index: kernel/generic/src/proc/thread.c
===================================================================
--- kernel/generic/src/proc/thread.c	(revision ea7890e7d40b57d264d11b6a6ded9dd8c6454424)
+++ kernel/generic/src/proc/thread.c	(revision 566f5e5c2e933d72fd5d40b30c7da09eb035d5ea)
@@ -79,5 +79,5 @@
 	"Entering",
 	"Exiting",
-	"JoinMe"
+	"Lingering"
 }; 
 
@@ -357,5 +357,5 @@
 void thread_destroy(thread_t *t)
 {
-	ASSERT(t->state == Exiting || t->state == JoinMe);
+	ASSERT(t->state == Exiting || t->state == Lingering);
 	ASSERT(t->task);
 	ASSERT(t->cpu);
@@ -521,6 +521,6 @@
 /** Detach thread.
  *
  * Mark the thread as detached, if the thread is already in the JoinMe state,
  * deallocate its resources.
  *
  * @param t Thread to be detached.
@@ -537,5 +537,5 @@
 	spinlock_lock(&t->lock);
 	ASSERT(!t->detached);
-	if (t->state == JoinMe) {
+	if (t->state == Lingering) {
 		thread_destroy(t);	/* unlocks &t->lock */
 		interrupts_restore(ipl);
@@ -521,6 +521,6 @@
 /** Detach thread.
  *
- * Mark the thread as detached, if the thread is already in the JoinMe state,
- * deallocate its resources.
+ * Mark the thread as detached, if the thread is already in the Lingering
+ * state, deallocate its resources.
  *
  * @param t Thread to be detached.
